@@ -466,13 +466,7 @@ class CallTracer(vm.VirtualMachine):
     for name, var in defs.items():
       if name in output.TOP_LEVEL_IGNORE or self._is_builtin(name, var.data):
         continue
-      options = []
-      for value, is_annotation in pytd_convert.get_annotated_values(
-          self.exitpoint, name, var, annots):
-        if is_annotation:
-          data.append(pytd.Constant(name, value))
-        else:
-          options.append(value)
+      options = var.FilteredData(self.exitpoint, strict=False)
       if (len(options) > 1 and
           not all(isinstance(o, abstract.FUNCTION_TYPES) for o in options)):
         # It's ambiguous whether this is a type, a function or something
@@ -588,7 +582,13 @@ class CallTracer(vm.VirtualMachine):
   def _check_return(self, node, actual, formal):
     if not self.options.report_errors:
       return True
-    bad = self.matcher.bad_matches(actual, formal, node)
+    views = abstract_utils.get_views([actual], node)
+    # Check for typevars in the return value first, since bad_matches
+    # expects not to get any.
+    bad = [view for view in views
+           if actual in view and view[actual].data.formal]
+    if not bad:
+      bad = self.matcher.bad_matches(actual, formal, node)
     if bad:
       with self.convert.pytd_convert.produce_detailed_output():
         combined = pytd_utils.JoinTypes(
