@@ -7,6 +7,7 @@ import textwrap
 from pytype import config
 from pytype import file_utils
 from pytype import load_pytd
+from pytype import utils
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.pytd import serialize_ast
@@ -18,9 +19,9 @@ import unittest
 class ImportPathsTest(unittest.TestCase):
   """Tests for load_pytd.py."""
 
-  PYTHON_VERSION = (2, 7)
+  python_version = (2, 7)
 
-  def testFilepathToModule(self):
+  def test_filepath_to_module(self):
     # (filename, pythonpath, expected)
     test_cases = [
         ("foo/bar/baz.py", [""], "foo.bar.baz"),
@@ -43,78 +44,78 @@ class ImportPathsTest(unittest.TestCase):
       module = load_pytd.get_module_name(filename, pythonpath)
       self.assertEqual(module, expected)
 
-  def testBuiltinSys(self):
-    loader = load_pytd.Loader("base", self.PYTHON_VERSION)
+  def test_builtin_sys(self):
+    loader = load_pytd.Loader("base", self.python_version)
     ast = loader.import_name("sys")
     self.assertTrue(ast.Lookup("sys.exit"))
 
-  def testBasic(self):
+  def test_basic(self):
     with file_utils.Tempdir() as d:
       d.create_file("path/to/some/module.pyi", "def foo(x:int) -> str")
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       ast = loader.import_name("path.to.some.module")
       self.assertTrue(ast.Lookup("path.to.some.module.foo"))
 
-  def testPath(self):
+  def test_path(self):
     with file_utils.Tempdir() as d1:
       with file_utils.Tempdir() as d2:
         d1.create_file("dir1/module1.pyi", "def foo1() -> str")
         d2.create_file("dir2/module2.pyi", "def foo2() -> str")
         loader = load_pytd.Loader(
-            "base", self.PYTHON_VERSION, pythonpath=[d1.path, d2.path])
+            "base", self.python_version, pythonpath=[d1.path, d2.path])
         module1 = loader.import_name("dir1.module1")
         module2 = loader.import_name("dir2.module2")
         self.assertTrue(module1.Lookup("dir1.module1.foo1"))
         self.assertTrue(module2.Lookup("dir2.module2.foo2"))
 
-  def testInit(self):
+  def test_init(self):
     with file_utils.Tempdir() as d1:
       d1.create_file("baz/__init__.pyi", "x = ... # type: int")
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d1.path])
+          "base", self.python_version, pythonpath=[d1.path])
       self.assertTrue(loader.import_name("baz").Lookup("baz.x"))
 
-  def testBuiltins(self):
+  def test_builtins(self):
     with file_utils.Tempdir() as d:
       d.create_file("foo.pyi", "x = ... # type: int")
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       mod = loader.import_name("foo")
       self.assertEqual("__builtin__.int", mod.Lookup("foo.x").type.cls.name)
       self.assertEqual("__builtin__.int", mod.Lookup("foo.x").type.name)
 
-  def testNoInit(self):
+  def test_no_init(self):
     with file_utils.Tempdir() as d:
       d.create_directory("baz")
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       self.assertTrue(loader.import_name("baz"))
 
-  def testNoInitImportsMap(self):
+  def test_no_init_imports_map(self):
     with file_utils.Tempdir() as d:
       d.create_directory("baz")
       os.chdir(d.path)
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, imports_map={}, pythonpath=[""])
+          "base", self.python_version, imports_map={}, pythonpath=[""])
       self.assertFalse(loader.import_name("baz"))
 
-  def testStdlib(self):
-    loader = load_pytd.Loader("base", self.PYTHON_VERSION)
+  def test_stdlib(self):
+    loader = load_pytd.Loader("base", self.python_version)
     ast = loader.import_name("StringIO")
     self.assertTrue(ast.Lookup("StringIO.StringIO"))
 
-  def testDeepDependency(self):
+  def test_deep_dependency(self):
     with file_utils.Tempdir() as d:
       d.create_file("module1.pyi", "def get_bar() -> module2.Bar")
       d.create_file("module2.pyi", "class Bar:\n  pass")
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       module1 = loader.import_name("module1")
       f, = module1.Lookup("module1.get_bar").signatures
       self.assertEqual("module2.Bar", f.return_type.cls.name)
 
-  def testCircularDependency(self):
+  def test_circular_dependency(self):
     with file_utils.Tempdir() as d:
       d.create_file("foo.pyi", """
         def get_bar() -> bar.Bar
@@ -127,7 +128,7 @@ class ImportPathsTest(unittest.TestCase):
           pass
       """)
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       foo = loader.import_name("foo")
       bar = loader.import_name("bar")
       f1, = foo.Lookup("foo.get_bar").signatures
@@ -135,7 +136,7 @@ class ImportPathsTest(unittest.TestCase):
       self.assertEqual("bar.Bar", f1.return_type.cls.name)
       self.assertEqual("foo.Foo", f2.return_type.cls.name)
 
-  def testRelative(self):
+  def test_relative(self):
     with file_utils.Tempdir() as d:
       d.create_file("__init__.pyi", "base = ...  # type: ?")
       d.create_file("path/__init__.pyi", "path = ...  # type: ?")
@@ -143,7 +144,7 @@ class ImportPathsTest(unittest.TestCase):
       d.create_file("path/to/some/__init__.pyi", "some = ...  # type: ?")
       d.create_file("path/to/some/module.pyi", "")
       loader = load_pytd.Loader("path.to.some.module",
-                                self.PYTHON_VERSION,
+                                self.python_version,
                                 pythonpath=[d.path])
       some = loader.import_relative(1)
       to = loader.import_relative(2)
@@ -153,11 +154,11 @@ class ImportPathsTest(unittest.TestCase):
       self.assertTrue(to.Lookup("path.to.to"))
       self.assertTrue(path.Lookup("path.path"))
 
-  def testTypeShed(self):
-    loader = load_pytd.Loader("base", self.PYTHON_VERSION)
+  def test_typeshed(self):
+    loader = load_pytd.Loader("base", self.python_version)
     self.assertTrue(loader.import_name("UserDict"))
 
-  def testResolveAlias(self):
+  def test_resolve_alias(self):
     with file_utils.Tempdir() as d:
       d.create_file("module1.pyi", """
           from typing import List
@@ -167,12 +168,12 @@ class ImportPathsTest(unittest.TestCase):
           def f() -> module1.x
       """)
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, pythonpath=[d.path])
+          "base", self.python_version, pythonpath=[d.path])
       module2 = loader.import_name("module2")
       f, = module2.Lookup("module2.f").signatures
       self.assertEqual("List[int]", pytd_utils.Print(f.return_type))
 
-  def testImportMapCongruence(self):
+  def test_import_map_congruence(self):
     with file_utils.Tempdir() as d:
       foo_path = d.create_file("foo.pyi", "class X: ...")
       bar_path = d.create_file("bar.pyi", "X = ...  # type: another.foo.X")
@@ -187,7 +188,7 @@ class ImportPathsTest(unittest.TestCase):
       # We cannot use tweak(imports_info=...) because that doesn't trigger
       # post-processing and we need an imports_map for the loader.
       loader = load_pytd.Loader(
-          "base", self.PYTHON_VERSION, imports_map=imports_map, pythonpath=[""])
+          "base", self.python_version, imports_map=imports_map, pythonpath=[""])
       normal = loader.import_name("foo")
       self.assertEqual("foo", normal.name)
       loader.import_name("bar")  # check that we can resolve against another.foo
@@ -207,19 +208,19 @@ class ImportPathsTest(unittest.TestCase):
       self.assertEqual("empty1", empty1.name)
       self.assertEqual("empty2", empty2.name)
 
-  def testPackageRelativeImport(self):
+  def test_package_relative_import(self):
     with file_utils.Tempdir() as d:
       d.create_file("pkg/foo.pyi", "class X: ...")
       d.create_file("pkg/bar.pyi", """
           from .foo import X
           y = ...  # type: X""")
       loader = load_pytd.Loader(
-          "pkg.bar", self.PYTHON_VERSION, pythonpath=[d.path])
+          "pkg.bar", self.python_version, pythonpath=[d.path])
       bar = loader.import_name("pkg.bar")
       f = bar.Lookup("pkg.bar.y")
       self.assertEqual("pkg.foo.X", f.type.name)
 
-  def testDirectoryImport(self):
+  def test_directory_import(self):
     with file_utils.Tempdir() as d:
       d.create_file("pkg/sub/__init__.pyi", """
           from .foo import *
@@ -229,11 +230,11 @@ class ImportPathsTest(unittest.TestCase):
       d.create_file("pkg/sub/bar.pyi", """
           from .foo import X
           y = ...  # type: X""")
-      loader = load_pytd.Loader("pkg", self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader("pkg", self.python_version, pythonpath=[d.path])
       ast = loader.import_name("pkg.sub")
       self.assertTrue(ast.Lookup("pkg.sub.X"))
 
-  def testDiamondImport(self):
+  def test_diamond_import(self):
     """Should not fail on importing a module via two paths."""
     with file_utils.Tempdir() as d:
       d.create_file("pkg/sub/__init__.pyi", """
@@ -245,14 +246,14 @@ class ImportPathsTest(unittest.TestCase):
           from .baz import X""")
       d.create_file("pkg/sub/baz.pyi", """
           class X: ...""")
-      loader = load_pytd.Loader("pkg", self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader("pkg", self.python_version, pythonpath=[d.path])
       ast = loader.import_name("pkg.sub")
       self.assertTrue(ast.Lookup("pkg.sub.X"))
 
-  def testGetResolvedModules(self):
+  def test_get_resolved_modules(self):
     with file_utils.Tempdir() as d:
       filename = d.create_file("dir/module.pyi", "def foo() -> str")
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       ast = loader.import_name("dir.module")
       modules = loader.get_resolved_modules()
       self.assertEqual(set(modules), {"__builtin__", "typing", "dir.module"})
@@ -261,7 +262,7 @@ class ImportPathsTest(unittest.TestCase):
       self.assertEqual(module.filename, filename)
       self.assertEqual(module.ast, ast)
 
-  def testCircularImport(self):
+  def test_circular_import(self):
     with file_utils.Tempdir() as d:
       d.create_file("os2/__init__.pyi", """
         from . import path as path
@@ -274,12 +275,12 @@ class ImportPathsTest(unittest.TestCase):
         _PathType = bytes
         def samestat(stat1: os2.stat_result) -> bool: ...
       """)
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       ast = loader.import_name("os2.path")
       self.assertEqual(ast.Lookup("os2.path._PathType").type.name,
                        "__builtin__.str")
 
-  def testCircularImportWithExternalType(self):
+  def test_circular_import_with_external_type(self):
     with file_utils.Tempdir() as d:
       d.create_file("os2/__init__.pyi", """
         from posix2 import stat_result as stat_result
@@ -293,41 +294,41 @@ class ImportPathsTest(unittest.TestCase):
         def samestate(stat1: os2.stat_result) -> bool: ...
       """)
       d.create_file("posix2.pyi", "class stat_result: ...")
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       # Make sure all three modules were resolved properly.
       loader.import_name("os2")
       loader.import_name("os2.path")
       loader.import_name("posix2")
 
-  def testUnionAlias(self):
+  def test_union_alias(self):
     with file_utils.Tempdir() as d:
       d.create_file("test.pyi", """
         from typing import Union as _UnionT
         x: _UnionT[int, str]
       """)
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       ast = loader.import_name("test")
       x = ast.Lookup("test.x")
       self.assertIsInstance(x.type, pytd.UnionType)
 
-  def testOptionalAlias(self):
+  def test_optional_alias(self):
     with file_utils.Tempdir() as d:
       d.create_file("test.pyi", """
         from typing import Optional as _OptionalT
         x: _OptionalT[int]
       """)
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       ast = loader.import_name("test")
       x = ast.Lookup("test.x")
       self.assertIsInstance(x.type, pytd.UnionType)
 
-  def testIntersectionAlias(self):
+  def test_intersection_alias(self):
     with file_utils.Tempdir() as d:
       d.create_file("test.pyi", """
         from typing import Intersection as _IntersectionT
         x: _IntersectionT[int, str]
       """)
-      loader = load_pytd.Loader(None, self.PYTHON_VERSION, pythonpath=[d.path])
+      loader = load_pytd.Loader(None, self.python_version, pythonpath=[d.path])
       ast = loader.import_name("test")
       x = ast.Lookup("test.x")
       self.assertIsInstance(x.type, pytd.IntersectionType)
@@ -338,9 +339,9 @@ _Module = collections.namedtuple("_", ["module_name", "file_name"])
 
 class PickledPyiLoaderTest(unittest.TestCase):
 
-  PYTHON_VERSION = (2, 7)
+  python_version = (2, 7)
 
-  def _CreateFiles(self, tempdir):
+  def _create_files(self, tempdir):
     src = """
         import module2
         from typing import List
@@ -364,55 +365,55 @@ class PickledPyiLoaderTest(unittest.TestCase):
             pass
     """)
 
-  def _GetPath(self, tempdir, filename):
+  def _get_path(self, tempdir, filename):
     return os.path.join(tempdir.path, filename)
 
-  def _LoadAst(self, tempdir, module):
+  def _load_ast(self, tempdir, module):
     loader = load_pytd.Loader(
-        base_module=module.module_name, python_version=self.PYTHON_VERSION,
+        base_module=module.module_name, python_version=self.python_version,
         pythonpath=[tempdir.path])
     return loader, loader.load_file(
-        module.module_name, self._GetPath(tempdir, module.file_name))
+        module.module_name, self._get_path(tempdir, module.file_name))
 
-  def _PickleModules(self, loader, tempdir, *modules):
+  def _pickle_modules(self, loader, tempdir, *modules):
     for module in modules:
       serialize_ast.StoreAst(
           loader._modules[module.module_name].ast,
-          self._GetPath(tempdir, module.file_name + ".pickled"))
+          self._get_path(tempdir, module.file_name + ".pickled"))
 
-  def _LoadPickledModule(self, tempdir, module):
+  def _load_pickled_module(self, tempdir, module):
     pickle_loader = load_pytd.PickledPyiLoader(
-        base_module=None, python_version=self.PYTHON_VERSION,
+        base_module=None, python_version=self.python_version,
         pythonpath=[tempdir.path])
     return pickle_loader.load_file(
-        module.module_name, self._GetPath(tempdir, module.file_name))
+        module.module_name, self._get_path(tempdir, module.file_name))
 
-  def testLoadWithSameModuleName(self):
+  def test_load_with_same_module_name(self):
     with file_utils.Tempdir() as d:
-      self._CreateFiles(tempdir=d)
+      self._create_files(tempdir=d)
       module1 = _Module(module_name="foo.bar.module1", file_name="module1.pyi")
       module2 = _Module(module_name="module2", file_name="module2.pyi")
-      loader, ast = self._LoadAst(tempdir=d, module=module1)
-      self._PickleModules(loader, d, module1, module2)
-      pickled_ast_filename = self._GetPath(d, module1.file_name + ".pickled")
+      loader, ast = self._load_ast(tempdir=d, module=module1)
+      self._pickle_modules(loader, d, module1, module2)
+      pickled_ast_filename = self._get_path(d, module1.file_name + ".pickled")
       result = serialize_ast.StoreAst(ast, pickled_ast_filename)
       self.assertIsNone(result)
 
-      loaded_ast = self._LoadPickledModule(d, module1)
+      loaded_ast = self._load_pickled_module(d, module1)
       self.assertTrue(loaded_ast)
       self.assertIsNot(loaded_ast, ast)
       self.assertTrue(pytd_utils.ASTeq(ast, loaded_ast))
       loaded_ast.Visit(visitors.VerifyLookup())
 
-  def testStarImport(self):
+  def test_star_import(self):
     with file_utils.Tempdir() as d:
       d.create_file("foo.pyi", "class A(object): ...")
       d.create_file("bar.pyi", "from foo import *")
       foo = _Module(module_name="foo", file_name="foo.pyi")
       bar = _Module(module_name="bar", file_name="bar.pyi")
-      loader, _ = self._LoadAst(d, module=bar)
-      self._PickleModules(loader, d, foo, bar)
-      loaded_ast = self._LoadPickledModule(d, bar)
+      loader, _ = self._load_ast(d, module=bar)
+      self._pickle_modules(loader, d, foo, bar)
+      loaded_ast = self._load_pickled_module(d, bar)
       loaded_ast.Visit(visitors.VerifyLookup())
       self.assertMultiLineEqual(pytd_utils.Print(loaded_ast),
                                 textwrap.dedent("""
@@ -420,20 +421,20 @@ class PickledPyiLoaderTest(unittest.TestCase):
 
         bar.A = foo.A""").lstrip())
 
-  def testFunctionAlias(self):
+  def test_function_alias(self):
     with file_utils.Tempdir() as d:
       d.create_file("foo.pyi", """
         def f(): ...
         g = f
       """)
       foo = _Module(module_name="foo", file_name="foo.pyi")
-      loader, _ = self._LoadAst(d, module=foo)
-      self._PickleModules(loader, d, foo)
-      loaded_ast = self._LoadPickledModule(d, foo)
+      loader, _ = self._load_ast(d, module=foo)
+      self._pickle_modules(loader, d, foo)
+      loaded_ast = self._load_pickled_module(d, foo)
       g = loaded_ast.Lookup("foo.g")
       self.assertEqual(g.type.function, loaded_ast.Lookup("foo.f"))
 
-  def testPackageRelativeImport(self):
+  def test_package_relative_import(self):
     with file_utils.Tempdir() as d:
       d.create_file("pkg/foo.pyi", "class X: ...")
       d.create_file("pkg/bar.pyi", """
@@ -441,12 +442,12 @@ class PickledPyiLoaderTest(unittest.TestCase):
           y = ...  # type: X""")
       foo = _Module(module_name="pkg.foo", file_name="pkg/foo.pyi")
       bar = _Module(module_name="pkg.bar", file_name="pkg/bar.pyi")
-      loader, _ = self._LoadAst(d, module=bar)
-      self._PickleModules(loader, d, foo, bar)
-      loaded_ast = self._LoadPickledModule(d, bar)
+      loader, _ = self._load_ast(d, module=bar)
+      self._pickle_modules(loader, d, foo, bar)
+      loaded_ast = self._load_pickled_module(d, bar)
       loaded_ast.Visit(visitors.VerifyLookup())
 
-  def testPickledBuiltins(self):
+  def test_pickled_builtins(self):
     with file_utils.Tempdir() as d:
       filename = d.create_file("builtins.pickle")
       foo_path = d.create_file("foo.pickle", """
@@ -454,11 +455,11 @@ class PickledPyiLoaderTest(unittest.TestCase):
         tz = ...  # type: datetime.tzinfo
       """)
       # save builtins
-      load_pytd.Loader("base", self.PYTHON_VERSION).save_to_pickle(filename)
+      load_pytd.Loader("base", self.python_version).save_to_pickle(filename)
       # load builtins
       loader = load_pytd.PickledPyiLoader.load_from_pickle(
           filename, "base",
-          python_version=self.PYTHON_VERSION,
+          python_version=self.python_version,
           imports_map={"foo": foo_path},
           pythonpath=[""])
       # test import
@@ -472,25 +473,26 @@ class PickledPyiLoaderTest(unittest.TestCase):
 class Python3Test(unittest.TestCase):
   """Tests for load_pytd.py on (target) Python 3."""
 
-  PYTHON_VERSION = (3, 6)
+  python_version = utils.full_version_from_major(3)
 
   def setUp(self):
     super(Python3Test, self).setUp()
-    self.options = config.Options.create(python_version=self.PYTHON_VERSION)
+    self.options = config.Options.create(python_version=self.python_version)
 
-  def testPython3Builtins(self):
-    # Test that we read python3 builtins from builtin.pytd if we pass a (3, 6)
+  def test_python3_builtins(self):
+    # Test that we read python3 builtins from builtin.pytd if we pass a python3
     # version to the loader.
     with file_utils.Tempdir() as d:
       d.create_file("a.pyi", """
-          from typing import AsyncGenerator
-          class A(AsyncGenerator[str]): ...""")
+          from typing import AsyncContextManager
+          class A(AsyncContextManager[str]): ...""")
       loader = load_pytd.Loader("base",
-                                python_version=self.PYTHON_VERSION,
+                                python_version=self.python_version,
                                 pythonpath=[d.path])
       a = loader.import_name("a")
       cls = a.Lookup("a.A")
-      self.assertEqual("AsyncGenerator[str]", pytd_utils.Print(cls.parents[0]))
+      self.assertEqual("AsyncContextManager[str]",
+                       pytd_utils.Print(cls.parents[0]))
 
 
 if __name__ == "__main__":
