@@ -110,8 +110,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           param_values = [self.vm.convert.unsolvable]
         if (param_values == [self.vm.convert.unsolvable] and
             isinstance(v, abstract.ParameterizedClass) and
-            not self.vm.annotations_util.get_type_parameters(
-                v.get_formal_type_parameter(t))):
+            not v.get_formal_type_parameter(t).formal):
           # When the instance's parameter value is unsolvable, we can get a
           # more precise type from the class. Note that we need to be careful
           # not to introduce unbound type parameters.
@@ -224,8 +223,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
         return pytd.NamedType("typing.Callable")
       if len(signatures) == 1:
         val = self.signature_to_callable(signatures[0], self.vm)
-        if (not isinstance(v, abstract.PYTD_FUNCTION_TYPES) or
-            not self.vm.annotations_util.get_type_parameters(val)):
+        if not isinstance(v, abstract.PYTD_FUNCTION_TYPES) or not val.formal:
           # This is a workaround to make sure we don't put unexpected type
           # parameters in call traces.
           return self.value_instance_to_pytd_type(node, val, None, seen, view)
@@ -260,9 +258,15 @@ class Converter(utils.VirtualMachineWeakrefMixin):
                                   for o in v.options))
     elif isinstance(v, special_builtins.SuperInstance):
       return pytd.NamedType("__builtin__.super")
-    elif isinstance(v, (abstract.Unsolvable, abstract.TypeParameter)):
+    elif isinstance(v, abstract.TypeParameter):
       # Arguably, the type of a type parameter is NamedType("typing.TypeVar"),
-      # but pytype doesn't know how to handle that, so let's just go with Any.
+      # but pytype doesn't know how to handle that, so let's just go with Any
+      # unless self._detailed is set.
+      if self._detailed:
+        return pytd.NamedType("typing.TypeVar")
+      else:
+        return pytd.AnythingType()
+    elif isinstance(v, abstract.Unsolvable):
       return pytd.AnythingType()
     elif isinstance(v, abstract.Unknown):
       return pytd.NamedType(v.class_name)
@@ -359,14 +363,13 @@ class Converter(utils.VirtualMachineWeakrefMixin):
         yield name, pytd_utils.JoinTypes(
             value.get_instance_type(node) for value in annots[name].data)
 
-  def _function_call_to_return_type(
-      self, sig, node, v, seen_return, num_returns):
+  def _function_call_to_return_type(self, node, v, seen_return, num_returns):
     """Get a function call's pytd return type."""
-    if sig.has_return_annotation:
+    if v.signature.has_return_annotation:
       if v.is_coroutine():
         ret = abstract.Coroutine.make(self.vm, v, node).to_type(node)
       else:
-        ret = sig.annotations["return"].get_instance_type(node)
+        ret = v.signature.annotations["return"].get_instance_type(node)
     else:
       ret = seen_return.data.to_type(node)
       if isinstance(ret, pytd.NothingType) and num_returns == 1:
@@ -376,49 +379,59 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           assert isinstance(seen_return.data, typing_overlay.NoReturn)
     return ret
 
+  def _function_call_combination_to_signature(
+      self, func, call_combination, num_combinations):
+    node_after, combination, return_value = call_combination
+    params = []
+    for i, (name, kwonly, optional) in enumerate(func.get_parameters()):
+      if i < func.nonstararg_count and name in func.signature.annotations:
+        t = func.signature.annotations[name].get_instance_type(node_after)
+      else:
+        t = combination[name].data.to_type(node_after)
+      # Python uses ".0" etc. for the names of parameters that are tuples,
+      # like e.g. in: "def f((x,  y), z)".
+      params.append(
+          pytd.Parameter(name.replace(".", "_"), t, kwonly, optional, None))
+    ret = self._function_call_to_return_type(
+        node_after, func, return_value, num_combinations)
+    if func.has_varargs():
+      if func.signature.varargs_name in func.signature.annotations:
+        annot = func.signature.annotations[func.signature.varargs_name]
+        typ = annot.get_instance_type(node_after)
+      else:
+        typ = pytd.NamedType("__builtin__.tuple")
+      starargs = pytd.Parameter(
+          func.signature.varargs_name, typ, False, True, None)
+    else:
+      starargs = None
+    if func.has_kwargs():
+      if func.signature.kwargs_name in func.signature.annotations:
+        annot = func.signature.annotations[func.signature.kwargs_name]
+        typ = annot.get_instance_type(node_after)
+      else:
+        typ = pytd.NamedType("__builtin__.dict")
+      starstarargs = pytd.Parameter(
+          func.signature.kwargs_name, typ, False, True, None)
+    else:
+      starstarargs = None
+    return pytd.Signature(
+        params=tuple(params),
+        starargs=starargs,
+        starstarargs=starstarargs,
+        return_type=ret,
+        exceptions=(),  # TODO(kramm): record exceptions
+        template=())
+
   def _function_to_def(self, node, v, function_name):
     """Convert an InterpreterFunction to a PyTD definition."""
     signatures = []
-    combinations = v.get_call_combinations(node)
-    for sig, node_after, combination, return_value in combinations:
-      params = []
-      for i, (name, kwonly, optional) in enumerate(v.get_parameters()):
-        if i < v.nonstararg_count and name in sig.annotations:
-          t = sig.annotations[name].get_instance_type(node_after)
-        else:
-          t = combination[name].data.to_type(node_after)
-        # Python uses ".0" etc. for the names of parameters that are tuples,
-        # like e.g. in: "def f((x,  y), z)".
-        params.append(
-            pytd.Parameter(name.replace(".", "_"), t, kwonly, optional, None))
-      ret = self._function_call_to_return_type(
-          sig, node_after, v, return_value, len(combinations))
-      if v.has_varargs():
-        if sig.varargs_name in sig.annotations:
-          annot = sig.annotations[sig.varargs_name]
-          typ = annot.get_instance_type(node_after)
-        else:
-          typ = pytd.NamedType("__builtin__.tuple")
-        starargs = pytd.Parameter(sig.varargs_name, typ, False, True, None)
-      else:
-        starargs = None
-      if v.has_kwargs():
-        if sig.kwargs_name in sig.annotations:
-          annot = sig.annotations[sig.kwargs_name]
-          typ = annot.get_instance_type(node_after)
-        else:
-          typ = pytd.NamedType("__builtin__.dict")
-        starstarargs = pytd.Parameter(sig.kwargs_name, typ, False, True, None)
-      else:
-        starstarargs = None
-      signatures.append(pytd.Signature(
-          params=tuple(params),
-          starargs=starargs,
-          starstarargs=starstarargs,
-          return_type=ret,
-          exceptions=(),  # TODO(kramm): record exceptions
-          template=()))
-
+    for func in v.signature_functions():
+      combinations = func.get_call_combinations(node)
+      num_combinations = len(combinations)
+      signatures.extend(
+          self._function_call_combination_to_signature(
+              func, combination, num_combinations)
+          for combination in combinations)
     return pytd.Function(name=function_name,
                          signatures=tuple(signatures),
                          kind=pytd.METHOD,
@@ -468,9 +481,9 @@ class Converter(utils.VirtualMachineWeakrefMixin):
     for val in options:
       if isinstance(val, abstract.InterpreterFunction):
         combinations = val.get_call_combinations(node)
-        for sig, node_after, _, return_value in combinations:
+        for node_after, _, return_value in combinations:
           types.append(self._function_call_to_return_type(
-              sig, node_after, val, return_value, len(combinations)))
+              node_after, val, return_value, len(combinations)))
       elif isinstance(val, abstract.PyTDFunction):
         types.extend(sig.pytd_sig.return_type for sig in val.signatures)
       else:
