@@ -27,9 +27,8 @@ POPS_BLOCK = 4096  # ends a block
 class Opcode(object):
   """An opcode without arguments."""
 
-  __slots__ = ("line", "index", "prev", "next",
-               "target", "block_target", "code",
-               "type_comment")
+  __slots__ = ("line", "index", "prev", "next", "target", "block_target",
+               "code", "annotation")
   FLAGS = 0
 
   def __init__(self, index, line):
@@ -37,7 +36,7 @@ class Opcode(object):
     self.line = line
     self.target = None
     self.code = None  # If we have a CodeType or OrderedCode parent
-    self.type_comment = None
+    self.annotation = None
 
   def at_line(self, line):
     """Return a new opcode simliar to this one but with a different line."""
@@ -52,8 +51,8 @@ class Opcode(object):
     return "%d: %d: %s" % (self.line, self.index, self.__class__.__name__)
 
   def __str__(self):
-    if self.type_comment:
-      return "%s  # type: %s" % (self.basic_str(), self.type_comment)
+    if self.annotation:
+      return "%s  # type: %s" % (self.basic_str(), self.annotation)
     else:
       return self.basic_str()
 
@@ -145,8 +144,8 @@ class OpcodeWithArg(Opcode):
 
   def __str__(self):
     out = "%s %s" % (self.basic_str(), self.pretty_arg)
-    if self.type_comment:
-      return "%s  # type: %s" % (out, self.type_comment)
+    if self.annotation:
+      return "%s  # type: %s" % (out, self.annotation)
     else:
       return out
 
@@ -958,7 +957,7 @@ python2_mapping = {
     147: MAP_ADD,
 }
 
-python3_mapping = {
+python_3_5_mapping = {
     1: POP_TOP,
     2: ROT_TWO,
     3: ROT_THREE,
@@ -969,6 +968,8 @@ python3_mapping = {
     11: UNARY_NEGATIVE,
     12: UNARY_NOT,
     15: UNARY_INVERT,
+    16: BINARY_MATRIX_MULTIPLY,
+    17: INPLACE_MATRIX_MULTIPLY,
     19: BINARY_POWER,
     20: BINARY_MULTIPLY,
     22: BINARY_MODULO,
@@ -982,7 +983,6 @@ python3_mapping = {
     50: GET_AITER,
     51: GET_ANEXT,
     52: BEFORE_ASYNC_WITH,
-    54: STORE_MAP,  # removed in Python 3.5.2
     55: INPLACE_ADD,
     56: INPLACE_SUBTRACT,
     57: INPLACE_MULTIPLY,
@@ -996,7 +996,7 @@ python3_mapping = {
     66: BINARY_OR,
     67: INPLACE_POWER,
     68: GET_ITER,
-    69: STORE_LOCALS,  # removed in Python 3.4
+    69: GET_YIELD_FROM_ITER,
     70: PRINT_EXPR,
     71: LOAD_BUILD_CLASS,  # PRINT_ITEM in Python 2
     72: YIELD_FROM,  # PRINT_NEWLINE in Python 2
@@ -1007,7 +1007,8 @@ python3_mapping = {
     78: INPLACE_XOR,
     79: INPLACE_OR,
     80: BREAK_LOOP,
-    81: WITH_CLEANUP,
+    81: WITH_CLEANUP_START,
+    82: WITH_CLEANUP_FINISH,
     83: RETURN_VALUE,
     84: IMPORT_STAR,
     86: YIELD_VALUE,
@@ -1065,6 +1066,11 @@ python3_mapping = {
     146: SET_ADD,
     147: MAP_ADD,
     148: LOAD_CLASSDEREF,  # not in Python 2
+    149: BUILD_LIST_UNPACK,
+    150: BUILD_MAP_UNPACK,
+    151: BUILD_MAP_UNPACK_WITH_CALL,
+    152: BUILD_TUPLE_UNPACK,
+    153: BUILD_SET_UNPACK,
     154: SETUP_ASYNC_WITH,
 }
 
@@ -1074,20 +1080,6 @@ def _overlay_mapping(mapping, new_entries):
   ret.update(new_entries)
   return dict((k, v) for k, v in six.iteritems(ret) if v is not None)
 
-python_3_5_mapping = _overlay_mapping(python3_mapping, {
-    16: BINARY_MATRIX_MULTIPLY,
-    17: INPLACE_MATRIX_MULTIPLY,
-    54: None,
-    69: GET_YIELD_FROM_ITER,  # STORE_LOCALS in Python 3.3
-    81: WITH_CLEANUP_START,  # WITH_CLEANUP in Python 3.4
-    82: WITH_CLEANUP_FINISH,
-    149: BUILD_LIST_UNPACK,
-    150: BUILD_MAP_UNPACK,
-    151: BUILD_MAP_UNPACK_WITH_CALL,
-    152: BUILD_TUPLE_UNPACK,
-    153: BUILD_SET_UNPACK,
-})
-
 python_3_6_mapping = _overlay_mapping(python_3_5_mapping, {
     85: SETUP_ANNOTATIONS,
     127: STORE_ANNOTATION,  # removed in Python 3.7
@@ -1276,7 +1268,6 @@ def dis(data, python_version, *args, **kwargs):
   assert major in (2, 3)
   mapping = {
       (2, 7): python2_mapping,
-      (3, 4): python3_mapping,
       (3, 5): python_3_5_mapping,
       (3, 6): python_3_6_mapping,
       (3, 7): python_3_7_mapping,
